## Summary

<!-- Brief description of what this PR does -->

## Changes

<!-- List the main changes in this PR -->

-

## Test Plan

<!-- How did you test these changes? -->

- [ ] Ran `uv run pytest tests/`
- [ ] Ran `uv run ruff check .`
- [ ] Tested manually with `dictare listen`

## Checklist

- [ ] I have read the [CONTRIBUTING](../CONTRIBUTING.md) guidelines
- [ ] My code follows the project's code style
- [ ] I have added tests for my changes (if applicable)
- [ ] I have updated the documentation (if applicable)
- [ ] I have updated CHANGELOG.md (if applicable)

## Related Issues

<!-- Link to any related issues: Fixes #123, Closes #456 -->
